%bcond_without bootstrap
%bcond_without tests
%bcond_with testpkg
%{?with_bootstrap:%undefine with_tests}

Summary:        Python library providing high-performance data analysis tools
Name:           python-pandas
Version:        1.5.3
Release:        5%{?dist}
License:        BSD-3-Clause AND (Apache-2.0 OR BSD-2-Clause) AND (BSD-3-Clause AND Apache-2.0) AND (BSD-3-Clause AND MIT) AND (BSD-3-Clause AND Python-2.0.1) AND MIT AND (BSD-3-Clause AND BSD-2-Clause)
URL:            https://pandas.pydata.org/
Source0:        https://github.com/pandas-dev/pandas/archive/v%{version}/pandas-%{version}.tar.gz

Patch3000:      https://github.com/pandas-dev/pandas/pull/49913.patch

%description
pandas is an open source, BSD-licensed library providing high-performance, easy-to-use data
structures and data analysis tools for the Python programming language.

%package -n python3-pandas
Summary:        Python library providing high-performance data analysis tools
BuildRequires:  gcc gcc-c++ python3-devel python3dist(numpy)
Provides:       bundled(python3dist(bottleneck))
Provides:       bundled(python3dist(dateutil))
Provides:       bundled(klib-khash) = 0.2.6
Provides:       bundled(musl-libc)
Provides:       bundled(python3dist(numpy)) = 1.7
Provides:       bundled(python3dist(packaging)) = 20.10.dev0^20210430gitae891fd
Provides:       bundled(python3dist(pyperclip)) = 1.7.0
Provides:       bundled(python3-libs)
Provides:       bundled(textreader)
Provides:       bundled(python3dist(sas7bdat))
Provides:       bundled(python3dist(scipy))
Provides:       bundled(python3dist(ujson))
Provides:       bundled(python3dist(xarray))

%if %{without bootstrap}
BuildRequires: python3dist(numexpr) python3dist(bottleneck) tzdata python3dist(matplotlib) python3dist(jinja2)
BuildRequires: python3dist(tabulate) python3dist(scipy) python3dist(xarray) python3dist(xlrd) python3dist(xlwt)
BuildRequires: python3dist(xlsxwriter) python3dist(openpyxl) python3dist(odfpy) python3dist(beautifulsoup4)
BuildRequires: python3dist(html5lib) python3dist(lxml) python3dist(sqlalchemy) python3dist(psycopg2)
BuildRequires: python3dist(pymysql) python3dist(tables) python3dist(pyarrow) python3dist(fsspec) python3dist(pyqt5)
BuildRequires: python3dist(qtpy) xclip xsel python3dist(brotli) python3dist(python-snappy) python3dist(zstandard)
BuildRequires: python3dist(pandas-datareader)
Requires:       python3dist(numexpr)
Requires:       python3dist(bottleneck)
Recommends: tzdata python3dist(matplotlib) python3dist(jinja2) python3dist(tabulate) python3dist(scipy)
Recommends: python3dist(xarray) python3dist(xlrd) python3dist(xlwt) python3dist(xlsxwriter)
Recommends: python3dist(openpyxl) python3dist(odfpy) python3dist(beautifulsoup4) python3dist(html5lib)
Recommends: python3dist(lxml) python3dist(sqlalchemy) python3dist(psycopg2) python3dist(pymysql)
Recommends: python3dist(tables) python3dist(pyarrow) python3dist(fsspec) python3dist(pyqt5) python3dist(qtpy)
Recommends: xclip xsel python3dist(brotli) python3dist(python-snappy) python3dist(zstandard)
Recommends: python3dist(pandas-datareader)
%endif

%description -n python3-pandas
pandas is an open source, BSD-licensed library providing high-performance, easy-to-use data
structures and data analysis tools for the Python programming language.

%if %{with testpkg}
%package -n python3-pandas+test
Summary:        Tests and test extras for Pandas
License:        BSD-3-Clause AND MIT
Requires:       python3-pandas = %{version}-%{release}

%description -n python3-pandas+test
These are the tests for python3-pandas. This package:

• Provides the “pandas.tests” package
• Makes sure the “test” extra dependencies are installed
• Carries additonal weak dependencies for running the tests
%endif

%if %{without bootstrap}
BuildRequires:  python3dist(boto3) python3dist(botocore)
BuildRequires:  python3dist(flask) python3dist(pytest-asyncio) python3dist(dask) python3dist(toolz) python3dist(partd)
BuildRequires:  python3dist(cloudpickle) python3dist(seaborn) python3dist(statsmodels) python3dist(cftime) python3dist(ipython)
Recommends:     python3dist(boto3) python3dist(botocore)
Recommends:     python3dist(flask) python3dist(pytest-asyncio) python3dist(dask) python3dist(cftime) python3dist(ipython)
Recommends:     python3dist(toolz) python3dist(partd) python3dist(cloudpickle) python3dist(seaborn) python3dist(statsmodels)
Provides:       bundled(R-haven)
Provides:       bundled(python3dist(bottleneck))
%endif

%prep
%autosetup -n pandas-%{version} -p1

rm -vf $(grep -rl '/\* Generated by Cython')

sed -r -i '/\boldest-supported-numpy\b/d' pyproject.toml
sed -r -i "s/(numpy>=)1\\.23\\.2(; python_version>='3\\.11')/\\11.22.0\\2/" setup.cfg

%generate_buildrequires
%pyproject_buildrequires -r %{?with_tests:-x test}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files pandas

%check
%if %{with tests}

m="${m-}${m+ and }not clipboard"

k="${k-}${k+ and }not test_bytes_exceed_2gb"

k="${k-}${k+ and }not test_html_template_extends_options"

%ifarch ppc64le
k="${k-}${k+ and }not test_rolling_var_numerical_issues"
%endif

k="${k-}${k+ and }not (TestExpressions and test_run_binary)"

mkdir -p _empty
cd _empty

export PYTHONHASHSEED="$(
  %{python3} -c 'import random; print(random.randint(1, 4294967295))'
)"

%constrain_build -c 1

%pytest -v '%{buildroot}%{python3_sitearch}/pandas' \
    --skip-slow \
    --skip-network \
    --skip-db \
    -m "${m-}" \
    -k "${k-}" \
    -n %{_smp_build_ncpus} \
    -r sxX

%endif

%files -n python3-pandas -f %{pyproject_files}
%license LICENSE LICENSES/
%doc README.md RELEASE.md
%exclude %{python3_sitearch}/pandas/tests

%if %{with testpkg}
%files -n python3-pandas+test
%{python3_sitearch}/pandas/tests
%ghost %{python3_sitearch}/*.dist-info
%endif

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.3-5
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.3-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.3-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.3-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 12 2023 Shuo Wang <abushwang@tencent.com> - 1.5.3-1
- initial build
